@@ -16,6 +16,7 @@
  * Boston, MA 02110-1301 USA.
  *
  * Copyright (C) 2013 Lanedo GmbH
+ * Copyright (C) 2013-2017 Aleksander Morgado <aleksander@aleksander.es>
  */
 
 #ifndef _QMI_VERSION_H_
@@ -33,6 +34,8 @@
  *
  * Evaluates to the major version number of libqmi-glib which this source
  * is compiled against.
+ *
+ * Since: 1.6
  */
 #define QMI_MAJOR_VERSION (1)
 
@@ -41,16 +44,20 @@
  *
  * Evaluates to the minor version number of libqmi-glib which this source
  * is compiled against.
+ *
+ * Since: 1.6
  */
-#define QMI_MINOR_VERSION (12)
+#define QMI_MINOR_VERSION (20)
 
 /**
  * QMI_MICRO_VERSION:
  *
  * Evaluates to the micro version number of libqmi-glib which this source
  * compiled against.
+ *
+ * Since: 1.6
  */
-#define QMI_MICRO_VERSION (8)
+#define QMI_MICRO_VERSION (2)
 
 /**
  * QMI_CHECK_VERSION:
@@ -58,12 +65,33 @@
  * @minor: minor version (e.g. 2 for version 1.2.5)
  * @micro: micro version (e.g. 5 for version 1.2.5)
  *
+ * Checks the version of the libqmi library that is being compiled against.
+ *
  * Returns: %TRUE if the version of the libqmi-glib header files
  * is the same as or newer than the passed-in version.
+ *
+ * Since: 1.6
  */
 #define QMI_CHECK_VERSION(major,minor,micro)                         \
     (QMI_MAJOR_VERSION > (major) ||                                  \
      (QMI_MAJOR_VERSION == (major) && QMI_MINOR_VERSION > (minor)) || \
      (QMI_MAJOR_VERSION == (major) && QMI_MINOR_VERSION == (minor) && QMI_MICRO_VERSION >= (micro)))
 
+/**
+ * QMI_MBIM_QMUX_SUPPORTED:
+ *
+ * Symbol to expose wether QMI over MBIM is supported. The symbol is always
+ * defined and set to either or 1 or 0.
+ *
+ * E.g.:
+ * |[
+ *  #if QMI_MBIM_QMUX_SUPPORTED
+ *      // do something
+ *  #endif
+ * ]|
+ *
+ * Since: 1.16
+ */
+#define QMI_MBIM_QMUX_SUPPORTED 1
+
 #endif /* _QMI_VERSION_H_ */
